@@ -1,5 +1,5 @@
 from examples.example_imports import *
-SceneArgs.use_online_tex = 0
+CONFIG.use_online_tex = True
 
 scene = EagerModeScene(screen_size=Size.bigger)
 theta = np.linspace(0, TAU, 100)
@@ -9,11 +9,12 @@ y = np.sin(theta)
 
 scene.plot(theta, y)
 
-scene.plot(x, y, x_label='t', y_label='f(t)',
+scene.plot(x, y,
+           x_label='t', y_label='f(t)',
            scale_ratio=1,
            )
 
 scene.show_plot()
-
+scene.get_run_time()
 scene.hold_on()
 
