@@ -1,5 +1,4 @@
 import os
-
 from sparrow.version_ops import VersionControl
 from tools import update_requirements, update_setup_cfg
 
@@ -10,8 +9,7 @@ vc.update_version()
 
 update_setup_cfg()
 os.system(f"git tag {vc.config['version']}")
-# To keep manimlib latest.
-update_requirements()
+
 vc.update_readme(readme_path="./README.md", license="MIT")
 vc.update_readme(readme_path="./README_zh.md", license="MIT")
 # os.system("yapf -i -r ./manim_express")
